@@ -1,3 +1,5 @@
+use crate::to_success_return_values;
+
 use super::to_value;
 use insta::assert_debug_snapshot;
 use serde::Serialize;
@@ -36,3 +38,8 @@ fn it_works_with_complex_structs() {
         map
     }));
 }
+
+#[test]
+fn it_serializes_return_value_list() {
+    assert_debug_snapshot!(to_success_return_values(vec![4i32, 10, 8843234, 100]));
+}
